//{{NO_DEPENDENCIES}}
// Microsoft Developer Studio generated include file.
// Used by ActiveDiatheke.rc
//
#define IDS_ACTIVEDIATHEKE              1
#define IDB_ACTIVEDIATHEKE              1
#define IDS_ACTIVEDIATHEKE_PPG          2
#define IDS_ACTIVEDIATHEKE_PPG_CAPTION  200
#define IDD_PROPPAGE_ACTIVEDIATHEKE     200
#define IDC_MAXVERSES                   205
#define IDC_VARIANTS                    206
#define IDC_LOCALE                      208
#define IDC_SCRIPT                      209
#define IDV_SEARCHTYPE                  210
#define IDC_OUTPUTFORMAT                211
#define IDC_OUTPUTENCODING              212
#define IDC_KEY                         213
#define IDC_BOOK                        214
#define IDC_SPIN1                       215
#define IDC_SPIN2                       216
#define IDC_STRONGS                     217
#define IDC_FOOTNOTES                   218
#define IDC_HEADINGS                    219
#define IDC_AUTOUPDATE                  220
#define IDC_MORPHOLOGY                  221
#define IDC_GREEKACCENTS                222
#define IDC_HEBREWPOINTS                223
#define IDC_HEBREWCANTILLATION          224
#define IDC_SCRIPREF                    226
#define IDC_ARSHAPE                     227
#define IDC_BIDIREORDER                 228

// Next default values for new objects
// 
#ifdef APSTUDIO_INVOKED
#ifndef APSTUDIO_READONLY_SYMBOLS
#define _APS_NEXT_RESOURCE_VALUE        202
#define _APS_NEXT_COMMAND_VALUE         32768
#define _APS_NEXT_CONTROL_VALUE         221
#define _APS_NEXT_SYMED_VALUE           101
#endif
#endif
